@@ -1,5 +1,5 @@
-"""QAM is a simple RPC Framework which uses the AMQP Protocoll as Transport Protocoll."""
-VERSION = (0, 2, 0)
+"""QAM is a simple RPC Framework which uses the AMQP Protocol as Transport Protocol."""
+VERSION = (0, 2, 1)
 __version__ = ".".join(map(str, VERSION))
 __author__ = "QAM Team"
 __contact__ = "qamteam@gmail.com"
